@@ -25,16 +25,8 @@ Exceptions, some API return codes, utility functions, a lot of urlfuncs
           compatible. PATCH/POST/DELETE operations needs review
 
 .. todo:: status API V2: testing of EVERYTHING is required """
-from .mambuconfig import apiurl
-from .mambuconfig import apiuser
-from .mambuconfig import apipwd
-
-from .mambuconfig import dbname
-from .mambuconfig import dbuser
-from .mambuconfig import dbpwd
-from .mambuconfig import dbhost
-from .mambuconfig import dbport
-from .mambuconfig import dbeng
+from .mambuconfig import (apipwd, apiurl, apiuser, dbeng, dbhost, dbname,
+                          dbport, dbpwd, dbuser)
 
 try:
     # python2
@@ -55,7 +47,7 @@ API_RETURN_CODES = {
     "INVALID_STATE_TRANSITION": 116,
     "INVALID_ACCOUNT_STATE_FOR_REPAYMENTS": 128,
     "INCONSISTENT_SCHEDULE_PRINCIPAL_DUE_WITH_LOAN_AMOUNT": 132,
-    }
+}
 """
 .. deprecated:: 0.8
    It's probably not useful. Besides, :any:`mambustruct.MambuStruct.connect()`
@@ -69,30 +61,41 @@ OUT_OF_BOUNDS_PAGINATION_LIMIT_VALUE = 500
 
 class MambuError(Exception):
     """Default exception"""
+
     pass
 
+
 class MambuCommError(MambuError):
     """Thrown when communication issues with Mambu arise"""
+
     pass
 
 
 # Connects to DB
 from sqlalchemy import create_engine
-def connectDb(engine   = dbeng,
-              user     = dbuser,
-              password = dbpwd,
-              host     = dbhost,
-              port     = dbport,
-              database = dbname,
-              params   = "?charset=utf8&use_unicode=1",
-              echoopt  = False):
+
+
+def connectDb(
+    engine=dbeng,
+    user=dbuser,
+    password=dbpwd,
+    host=dbhost,
+    port=dbport,
+    database=dbname,
+    params="?charset=utf8&use_unicode=1",
+    echoopt=False,
+):
     """Connect to database utility function.
 
     Uses SQLAlchemy ORM library.
 
     Useful when using schema modules in MambuPy
     """
-    return create_engine('%s://%s:%s@%s:%s/%s%s' % (engine, user, password, host, port, database, params), echo=echoopt)
+    return create_engine(
+        "%s://%s:%s@%s:%s/%s%s"
+        % (engine, user, password, host, port, database, params),
+        echo=echoopt,
+    )
 
 
 def getmambuurl(url=apiurl, *args, **kwargs):
@@ -109,10 +112,12 @@ def getmambuurl(url=apiurl, *args, **kwargs):
     mambuurl = "https://" + url + "/api/"
     return mambuurl
 
+
 ###*** Behold, the urlfuncs magic follows ***###
 # This things are the gateways for implementing parameters on requests done to
 # the Mambu REST API.
 
+
 def getbranchesurl(idbranch, *args, **kwargs):
     """Request Branches URL.
 
@@ -148,10 +153,16 @@ def getbranchesurl(idbranch, *args, **kwargs):
         except Exception:
             pass
 
-    branchidparam = "" if idbranch == "" else "/"+idbranch
-    url = getmambuurl(*args, **kwargs) + "branches" + branchidparam + ("" if len(getparams) == 0 else "?" + "&".join(getparams) )
+    branchidparam = "" if idbranch == "" else "/" + idbranch
+    url = (
+        getmambuurl(*args, **kwargs)
+        + "branches"
+        + branchidparam
+        + ("" if len(getparams) == 0 else "?" + "&".join(getparams))
+    )
     return url
 
+
 def getcentresurl(idcentre, *args, **kwargs):
     """Request Centres URL.
 
@@ -187,10 +198,16 @@ def getcentresurl(idcentre, *args, **kwargs):
         except Exception:
             pass
 
-    centreidparam = "" if idcentre == "" else "/"+idcentre
-    url = getmambuurl(*args, **kwargs) + "centres" + centreidparam + ("" if len(getparams) == 0 else "?" + "&".join(getparams) )
+    centreidparam = "" if idcentre == "" else "/" + idcentre
+    url = (
+        getmambuurl(*args, **kwargs)
+        + "centres"
+        + centreidparam
+        + ("" if len(getparams) == 0 else "?" + "&".join(getparams))
+    )
     return url
 
+
 def getrepaymentsurl(idcred, *args, **kwargs):
     """Request loan Repayments URL.
 
@@ -234,9 +251,16 @@ def getrepaymentsurl(idcred, *args, **kwargs):
         except Exception:
             pass
 
-    url = getmambuurl(*args,**kwargs) + "loans/" + idcred + "/repayments" + ("" if len(getparams) == 0 else "?" + "&".join(getparams) )
+    url = (
+        getmambuurl(*args, **kwargs)
+        + "loans/"
+        + idcred
+        + "/repayments"
+        + ("" if len(getparams) == 0 else "?" + "&".join(getparams))
+    )
     return url
 
+
 def getsavingssurl(idcred, *args, **kwargs):
     """Request loan savings URL.
 
@@ -272,9 +296,15 @@ def getsavingssurl(idcred, *args, **kwargs):
         except Exception:
             pass
 
-    url = getmambuurl(*args,**kwargs) + "savings/" + idcred + ("" if len(getparams) == 0 else "?" + "&".join(getparams) )
+    url = (
+        getmambuurl(*args, **kwargs)
+        + "savings/"
+        + idcred
+        + ("" if len(getparams) == 0 else "?" + "&".join(getparams))
+    )
     return url
 
+
 def getsavingfundingrepaymentsurl(idcred, loan_id, *args, **kwargs):
     """Request loan saving Repayments URL.
 
@@ -309,9 +339,18 @@ def getsavingfundingrepaymentsurl(idcred, loan_id, *args, **kwargs):
         except Exception:
             pass
 
-    url = getmambuurl(*args,**kwargs) + "savings/" + idcred + "/funding/" + loan_id + '/repayments' + ("" if len(getparams) == 0 else "?" + "&".join(getparams) )
+    url = (
+        getmambuurl(*args, **kwargs)
+        + "savings/"
+        + idcred
+        + "/funding/"
+        + loan_id
+        + "/repayments"
+        + ("" if len(getparams) == 0 else "?" + "&".join(getparams))
+    )
     return url
 
+
 def getsavingstransactionsurl(idcred, *args, **kwargs):
     """Request saving transaction URL.
 
@@ -347,9 +386,16 @@ def getsavingstransactionsurl(idcred, *args, **kwargs):
         except Exception:
             pass
 
-    url = getmambuurl(*args,**kwargs) + "savings/" + idcred + "/transactions/" + ("" if len(getparams) == 0 else "?" + "&".join(getparams) )
+    url = (
+        getmambuurl(*args, **kwargs)
+        + "savings/"
+        + idcred
+        + "/transactions/"
+        + ("" if len(getparams) == 0 else "?" + "&".join(getparams))
+    )
     return url
 
+
 def getsavingstransactionssearchurl(idcred, *args, **kwargs):
     """Request saving transaction URL.
 
@@ -384,9 +430,14 @@ def getsavingstransactionssearchurl(idcred, *args, **kwargs):
         except Exception:
             pass
 
-    url = getmambuurl(*args,**kwargs) + "savings/transactions/search" + ("" if len(getparams) == 0 else "?" + "&".join(getparams) )
+    url = (
+        getmambuurl(*args, **kwargs)
+        + "savings/transactions/search"
+        + ("" if len(getparams) == 0 else "?" + "&".join(getparams))
+    )
     return url
 
+
 def gettransactionchannelsurl(idcred, *args, **kwargs):
     """Transaction channels URL.
 
@@ -422,9 +473,15 @@ def gettransactionchannelsurl(idcred, *args, **kwargs):
         except Exception:
             pass
 
-    url = getmambuurl(*args,**kwargs) + "transactionchannels/" + idcred + ("" if len(getparams) == 0 else "?" + "&".join(getparams) )
+    url = (
+        getmambuurl(*args, **kwargs)
+        + "transactionchannels/"
+        + idcred
+        + ("" if len(getparams) == 0 else "?" + "&".join(getparams))
+    )
     return url
 
+
 def getloansurl(idcred, *args, **kwargs):
     """Request Loans URL.
 
@@ -471,20 +528,22 @@ def getloansurl(idcred, *args, **kwargs):
         except Exception:
             pass
         try:
-            getparams.append("creditOfficerUsername=%s" % kwargs["creditOfficerUsername"])
+            getparams.append(
+                "creditOfficerUsername=%s" % kwargs["creditOfficerUsername"]
+            )
         except Exception:
             pass
         try:
             getparams.append("startDate=%s" % kwargs["startDate"])
-        except Exception as ex:
+        except Exception:
             pass
         try:
             getparams.append("endDate=%s" % kwargs["endDate"])
-        except Exception as ex:
+        except Exception:
             pass
         try:
             getparams.append("fixedDaysOfMonth=%s" % kwargs["fixedDaysOfMonth"])
-        except Exception as ex:
+        except Exception:
             pass
         try:
             getparams.append("offset=%s" % kwargs["offset"])
@@ -495,10 +554,16 @@ def getloansurl(idcred, *args, **kwargs):
         except Exception:
             pass
 
-    idcredparam = "" if idcred == "" else "/"+idcred
-    url = getmambuurl(*args,**kwargs) + "loans" + idcredparam + ("" if len(getparams) == 0 else "?" + "&".join(getparams) )
+    idcredparam = "" if idcred == "" else "/" + idcred
+    url = (
+        getmambuurl(*args, **kwargs)
+        + "loans"
+        + idcredparam
+        + ("" if len(getparams) == 0 else "?" + "&".join(getparams))
+    )
     return url
 
+
 def getloanscustominformationurl(idcred, customfield="", *args, **kwargs):
     """Request Loan Custom Information URL.
 
@@ -508,9 +573,16 @@ def getloanscustominformationurl(idcred, customfield="", *args, **kwargs):
     .. todo:: status API V2: NOT compatible
     """
     loanidparam = "/" + idcred
-    url = getmambuurl(*args, **kwargs) + "loans" + loanidparam + "/custominformation" + ( ("/"+customfield) if customfield else "" )
+    url = (
+        getmambuurl(*args, **kwargs)
+        + "loans"
+        + loanidparam
+        + "/custominformation"
+        + (("/" + customfield) if customfield else "")
+    )
     return url
 
+
 def getusercustominformationurl(iduser, customfield="", *args, **kwargs):
     """Request User Custom Information URL.
 
@@ -520,9 +592,16 @@ def getusercustominformationurl(iduser, customfield="", *args, **kwargs):
     .. todo:: status API V2: NOT compatible
     """
     useridparam = "/" + iduser
-    url = getmambuurl(*args, **kwargs) + "users" + useridparam + "/custominformation" + ( ("/"+customfield) if customfield else "" )
+    url = (
+        getmambuurl(*args, **kwargs)
+        + "users"
+        + useridparam
+        + "/custominformation"
+        + (("/" + customfield) if customfield else "")
+    )
     return url
 
+
 def getgroupurl(idgroup, *args, **kwargs):
     """Request Groups URL.
 
@@ -555,7 +634,9 @@ def getgroupurl(idgroup, *args, **kwargs):
         except Exception:
             pass
         try:
-            getparams.append("creditOfficerUsername=%s" % kwargs["creditOfficerUsername"])
+            getparams.append(
+                "creditOfficerUsername=%s" % kwargs["creditOfficerUsername"]
+            )
         except Exception:
             pass
         try:
@@ -574,10 +655,16 @@ def getgroupurl(idgroup, *args, **kwargs):
             getparams.append("offset=%s" % kwargs["offset"])
         except Exception:
             pass
-    groupidparam = "" if idgroup == "" else "/"+idgroup
-    url = getmambuurl(*args,**kwargs) + "groups" + groupidparam + ( "" if len(getparams) == 0 else "?" + "&".join(getparams) )
+    groupidparam = "" if idgroup == "" else "/" + idgroup
+    url = (
+        getmambuurl(*args, **kwargs)
+        + "groups"
+        + groupidparam
+        + ("" if len(getparams) == 0 else "?" + "&".join(getparams))
+    )
     return url
 
+
 def getgrouploansurl(idgroup, *args, **kwargs):
     """Request Group loans URL.
 
@@ -618,9 +705,16 @@ def getgrouploansurl(idgroup, *args, **kwargs):
         except Exception:
             pass
     groupidparam = "/" + idgroup
-    url = getmambuurl(*args,**kwargs) + "groups" + groupidparam  + "/loans" + ( "" if len(getparams) == 0 else "?" + "&".join(getparams) )
+    url = (
+        getmambuurl(*args, **kwargs)
+        + "groups"
+        + groupidparam
+        + "/loans"
+        + ("" if len(getparams) == 0 else "?" + "&".join(getparams))
+    )
     return url
 
+
 def getgroupcustominformationurl(idgroup, customfield="", *args, **kwargs):
     """Request Group Custom Information URL.
 
@@ -632,9 +726,16 @@ def getgroupcustominformationurl(idgroup, customfield="", *args, **kwargs):
     .. todo:: status API V2: NOT compatible
     """
     groupidparam = "/" + idgroup
-    url = getmambuurl(*args, **kwargs) + "groups" + groupidparam + "/custominformation" + ( ("/"+customfield) if customfield else "" )
+    url = (
+        getmambuurl(*args, **kwargs)
+        + "groups"
+        + groupidparam
+        + "/custominformation"
+        + (("/" + customfield) if customfield else "")
+    )
     return url
 
+
 def gettransactionsurl(idcred, *args, **kwargs):
     """Request loan Transactions URL.
 
@@ -671,9 +772,16 @@ def gettransactionsurl(idcred, *args, **kwargs):
             getparams.append("limit=%s" % kwargs["limit"])
         except Exception:
             pass
-    url = getmambuurl(*args,**kwargs) + "loans/" + idcred + "/transactions" + ( "" if len(getparams) == 0 else "?" + "&".join(getparams) )
+    url = (
+        getmambuurl(*args, **kwargs)
+        + "loans/"
+        + idcred
+        + "/transactions"
+        + ("" if len(getparams) == 0 else "?" + "&".join(getparams))
+    )
     return url
 
+
 def getclienturl(idclient, *args, **kwargs):
     """Request Clients URL.
 
@@ -735,10 +843,16 @@ def getclienturl(idclient, *args, **kwargs):
             getparams.append("limit=%s" % kwargs["limit"])
         except Exception:
             pass
-    clientidparam = "" if idclient == "" else "/"+idclient
-    url = getmambuurl(*args,**kwargs) + "clients" + clientidparam + ( "" if len(getparams) == 0 else "?" + "&".join(getparams) )
+    clientidparam = "" if idclient == "" else "/" + idclient
+    url = (
+        getmambuurl(*args, **kwargs)
+        + "clients"
+        + clientidparam
+        + ("" if len(getparams) == 0 else "?" + "&".join(getparams))
+    )
     return url
 
+
 def getclientloansurl(idclient, *args, **kwargs):
     """Request Client loans URL.
 
@@ -779,9 +893,16 @@ def getclientloansurl(idclient, *args, **kwargs):
         except Exception:
             pass
     clientidparam = "/" + idclient
-    url = getmambuurl(*args,**kwargs) + "clients" + clientidparam  + "/loans" + ( "" if len(getparams) == 0 else "?" + "&".join(getparams) )
+    url = (
+        getmambuurl(*args, **kwargs)
+        + "clients"
+        + clientidparam
+        + "/loans"
+        + ("" if len(getparams) == 0 else "?" + "&".join(getparams))
+    )
     return url
 
+
 def getclientcustominformationurl(idclient, customfield="", *args, **kwargs):
     """Request Client Custom Information URL.
 
@@ -793,9 +914,16 @@ def getclientcustominformationurl(idclient, customfield="", *args, **kwargs):
     .. todo:: status API V2: NOT compatible
     """
     clientidparam = "/" + idclient
-    url = getmambuurl(*args, **kwargs) + "clients" + clientidparam + "/custominformation" + ( ("/"+customfield) if customfield else "" )
+    url = (
+        getmambuurl(*args, **kwargs)
+        + "clients"
+        + clientidparam
+        + "/custominformation"
+        + (("/" + customfield) if customfield else "")
+    )
     return url
 
+
 def getuserurl(iduser, *args, **kwargs):
     """Request Users URL.
 
@@ -835,10 +963,16 @@ def getuserurl(iduser, *args, **kwargs):
             getparams.append("limit=%s" % kwargs["limit"])
         except Exception:
             pass
-    useridparam = "" if iduser == "" else "/"+iduser
-    url = getmambuurl(*args,**kwargs) + "users" + useridparam + ( "" if len(getparams) == 0 else "?" + "&".join(getparams) )
+    useridparam = "" if iduser == "" else "/" + iduser
+    url = (
+        getmambuurl(*args, **kwargs)
+        + "users"
+        + useridparam
+        + ("" if len(getparams) == 0 else "?" + "&".join(getparams))
+    )
     return url
 
+
 def getproductsurl(idproduct, *args, **kwargs):
     """Request loan Products URL.
 
@@ -854,11 +988,12 @@ def getproductsurl(idproduct, *args, **kwargs):
     .. todo:: status API V2: NOT compatible. Current (2020-03) v2 only
               supports GETting a SINGLE product, not all of them
     """
-    productidparam = "" if idproduct == "" else "/"+idproduct
-    url = getmambuurl(*args,**kwargs) + "loanproducts" + productidparam
+    productidparam = "" if idproduct == "" else "/" + idproduct
+    url = getmambuurl(*args, **kwargs) + "loanproducts" + productidparam
     return url
 
-def gettasksurl(dummyId='', *args, **kwargs):
+
+def gettasksurl(dummyId="", *args, **kwargs):
     """Request Tasks URL.
 
     dummyId is used because MambuStruct always requires an Id from an
@@ -915,10 +1050,15 @@ def gettasksurl(dummyId='', *args, **kwargs):
         except Exception:
             pass
 
-    url = getmambuurl(*args,**kwargs) + "tasks" + ( "" if len(getparams) == 0 else "?" + "&".join(getparams) )
+    url = (
+        getmambuurl(*args, **kwargs)
+        + "tasks"
+        + ("" if len(getparams) == 0 else "?" + "&".join(getparams))
+    )
     return url
 
-def getactivitiesurl(dummyId='', *args, **kwargs):
+
+def getactivitiesurl(dummyId="", *args, **kwargs):
     """Request Activities URL.
 
     dummyId is used because MambuStruct always requires an Id from an
@@ -951,12 +1091,12 @@ def getactivitiesurl(dummyId='', *args, **kwargs):
         try:
             getparams.append("from=%s" % kwargs["fromDate"])
         except Exception:
-            getparams.append("from=%s" % '1900-01-01')
+            getparams.append("from=%s" % "1900-01-01")
 
         try:
             getparams.append("to=%s" % kwargs["toDate"])
         except Exception:
-            hoy = datetime.now().strftime('%Y-%m-%d')
+            hoy = datetime.now().strftime("%Y-%m-%d")
             getparams.append("to=%s" % hoy)
 
         try:
@@ -994,10 +1134,15 @@ def getactivitiesurl(dummyId='', *args, **kwargs):
         except Exception:
             pass
 
-    url = getmambuurl(*args,**kwargs) + "activities" + ( "" if len(getparams) == 0 else "?" + "&".join(getparams) )
+    url = (
+        getmambuurl(*args, **kwargs)
+        + "activities"
+        + ("" if len(getparams) == 0 else "?" + "&".join(getparams))
+    )
     return url
 
-def getrolesurl(idrole='', *args, **kwargs):
+
+def getrolesurl(idrole="", *args, **kwargs):
     """Request Roles URL.
 
     If idrole is set, you'll get a response adequate for a MambuRole
@@ -1009,9 +1154,12 @@ def getrolesurl(idrole='', *args, **kwargs):
 
     .. todo:: status API V2: NOT compatible. Apparently not yet implemented
     """
-    url = getmambuurl(*args,**kwargs) + "userroles" + (("/" + idrole) if idrole else "")
+    url = (
+        getmambuurl(*args, **kwargs) + "userroles" + (("/" + idrole) if idrole else "")
+    )
     return url
 
+
 def getpostdocumentsurl(identity="", *args, **kwargs):
     """Request to post documents URL.
 
@@ -1019,9 +1167,10 @@ def getpostdocumentsurl(identity="", *args, **kwargs):
     https://support.mambu.com/docs/attachments-api
 
     """
-    url = getmambuurl(*args,**kwargs) + "documents"
+    url = getmambuurl(*args, **kwargs) + "documents"
     return url
 
+
 ### No more urlfuncs from here ###
 
 ### More utility functions follow ###
@@ -1033,6 +1182,7 @@ def strip_tags(html):
     useless, so stripping them is a good idea.
     """
     from html.parser import HTMLParser
+
     class MLStripper(HTMLParser):
         """Aux class for stripping HTML tags.
 
@@ -1040,20 +1190,23 @@ def strip_tags(html):
         (they are rich text fields, I guess that's why). Sometimes they are
         useless, so stripping them is a good idea.
         """
+
         def __init__(self):
             try:
-                super().__init__() # required for python3
-            except TypeError as e:
-                pass # with python2 raises TypeError
+                super().__init__()  # required for python3
+            except TypeError:
+                pass  # with python2 raises TypeError
             self.reset()
             self.fed = []
+
         def handle_data(self, d):
             self.fed.append(d)
+
         def get_data(self):
-            return ''.join(self.fed)
+            return "".join(self.fed)
 
     s = MLStripper()
-    s.feed(html.replace("&nbsp;"," "))
+    s.feed(html.replace("&nbsp;", " "))
     return s.get_data()
 
 
@@ -1067,18 +1220,21 @@ def strip_consecutive_repeated_char(s, ch):
     This is a string processing function.
     """
     sdest = ""
-    for i,c in enumerate(s):
-        if i != 0 and s[i] == ch and s[i] == s[i-1]:
+    for i, c in enumerate(s):
+        if i != 0 and s[i] == ch and s[i] == s[i - 1]:
             continue
         sdest += s[i]
     return sdest
 
+
 if sys.version_info >= (3, 0):
     # python3
     from future.moves.urllib import parse as urlparse
 else:
     # python2
     import urlparse
+
+
 def iriToUri(iri):
     """Change an IRI (internationalized R) to an URI.
 
@@ -1091,6 +1247,7 @@ def iriToUri(iri):
     MambuUser object with them, I get a BIG problem because of the
     unicode chars there. Using this I solved the problem.
     """
+
     def urlEncodeNonAscii(b):
         """Encode Non ASCII chars to URL-friendly chars.
 
@@ -1098,7 +1255,8 @@ def iriToUri(iri):
         biggest shame is not me correctly handling it.
         """
         import re
-        return re.sub('[\x80-\xFF]', lambda c: '%%%02x' % ord(c.group(0)), b)
+
+        return re.sub("[\x80-\xFF]", lambda c: "%%%02x" % ord(c.group(0)), b)
 
     parts = urlparse.urlparse(iri)
     if sys.version_info < (3, 0):
@@ -1107,17 +1265,17 @@ def iriToUri(iri):
         for parti, part in enumerate(parts):
             try:
                 if parti != 1:
-                    partes.append(urlEncodeNonAscii(part.encode('utf-8')))
+                    partes.append(urlEncodeNonAscii(part.encode("utf-8")))
                 else:
-                    partes.append(part.encode('idna'))
-            except UnicodeDecodeError as ue:
-                partes.append(urlEncodeNonAscii(part.decode('latin')))
+                    partes.append(part.encode("idna"))
+            except UnicodeDecodeError:
+                partes.append(urlEncodeNonAscii(part.decode("latin")))
             except Exception:
                 raise Exception
         return urlparse.urlunparse(partes)
     else:
         # python3
-        uri = [part.decode('utf8') for parti, part in enumerate(parts.encode('utf8'))]
+        uri = [part.decode("utf8") for parti, part in enumerate(parts.encode("utf8"))]
         return urlparse.urlunparse(uri)
 
 
@@ -1130,17 +1288,20 @@ def encoded_dict(in_dict):
     for k, v in in_dict.items():
         if isinstance(v, unicode):
             if sys.version_info < (3, 0):
-                v = v.encode('utf8')
+                v = v.encode("utf8")
         elif isinstance(v, str):
             # Must be encoded in UTF-8
             if sys.version_info < (3, 0):
-                v.decode('utf8')
+                v.decode("utf8")
         out_dict[k] = v
     return out_dict
 
 
 from time import sleep
+
 import requests
+
+
 def backup_db(callback, bool_func, output_fname, *args, **kwargs):
     """Backup Mambu Database via REST API.
 
@@ -1187,36 +1348,47 @@ def backup_db(callback, bool_func, output_fname, *args, **kwargs):
     from datetime import datetime
 
     try:
-        verbose = kwargs['verbose']
+        verbose = kwargs["verbose"]
     except KeyError:
         verbose = False
     try:
-        retries = kwargs['retries']
+        retries = kwargs["retries"]
     except KeyError:
         retries = -1
     try:
-        force_download_latest = bool(kwargs['force_download_latest'])
+        force_download_latest = bool(kwargs["force_download_latest"])
     except KeyError:
         force_download_latest = False
     try:
-        headers = kwargs['headers']
+        headers = kwargs["headers"]
     except KeyError:
-        headers = {'content-type': 'application/json', 'Accept': 'application/vnd.mambu.v1+zip'}
+        headers = {
+            "content-type": "application/json",
+            "Accept": "application/vnd.mambu.v1+zip",
+        }
 
     if verbose:
-        log = open('/tmp/log_mambu_backup','a')
-        log.write(datetime.now().strftime('%Y-%m-%d %H:%M:%S') + " - Mambu DB Backup\n")
+        log = open("/tmp/log_mambu_backup", "a")
+        log.write(datetime.now().strftime("%Y-%m-%d %H:%M:%S") + " - Mambu DB Backup\n")
         log.flush()
 
-    user = kwargs.pop('user', apiuser)
-    pwd = kwargs.pop('pwd', apipwd)
-    data = {'callback' : callback}
+    user = kwargs.pop("user", apiuser)
+    pwd = kwargs.pop("pwd", apipwd)
+    data = {"callback": callback}
     try:
         posturl = iriToUri(getmambuurl(*args, **kwargs) + "database/backup")
         if verbose:
-            log.write("open url: "+posturl+"\n")
+            log.write("open url: " + posturl + "\n")
             log.flush()
-        resp = requests.post(posturl, data=data, headers={'content-type': 'application/json', 'Accept': 'application/vnd.mambu.v1+json'}, auth=(user, pwd))
+        resp = requests.post(
+            posturl,
+            data=data,
+            headers={
+                "content-type": "application/json",
+                "Accept": "application/vnd.mambu.v1+json",
+            },
+            auth=(user, pwd),
+        )
     except Exception as ex:
         mess = "Error requesting backup: %s" % repr(ex)
         if verbose:
@@ -1231,14 +1403,15 @@ def backup_db(callback, bool_func, output_fname, *args, **kwargs):
             log.close()
         raise MambuCommError(mess)
 
-    data['latest'] = True
+    data["latest"] = True
     while retries and not bool_func():
         if verbose:
             log.write("waiting...\n")
             log.flush()
         sleep(10)
         retries -= 1
-        if retries < 0: retries = -1
+        if retries < 0:
+            retries = -1
     if not retries:
         mess = "Tired of waiting, giving up..."
         if verbose:
@@ -1249,12 +1422,12 @@ def backup_db(callback, bool_func, output_fname, *args, **kwargs):
                 log.close()
             raise MambuError(mess)
         else:
-            data['latest'] = False
+            data["latest"] = False
     sleep(30)
 
     geturl = iriToUri(getmambuurl(*args, **kwargs) + "database/backup/LATEST")
     if verbose:
-        log.write("open url: "+geturl+"\n")
+        log.write("open url: " + geturl + "\n")
         log.flush()
     resp = requests.get(geturl, auth=(user, pwd), headers=headers)
 
